@@ -110,7 +110,7 @@ class Builder:
     def load_epp(self, parameters, can, can_suffix):
         matrix, = canmatrix.formats.load(
             can,
-            importType=can_suffix[1:],
+            import_type=can_suffix[1:],
         ).values()
         neo = epyqlib.canneo.Neo(
             matrix=matrix,
@@ -171,7 +171,7 @@ class Builder:
             directory_path.mkdir()
 
             for access_input in self.access_parameters:
-                node = self.get_or_create_parameter(name=access_input.node)
+                node = self.get_or_create_parameter(name=access_input.node.name)
 
                 node.value = access_input.value
 
